@@ -20,6 +20,7 @@
 
 #include <cassert>
 #include <cmath>
+#include <cstdlib>
 #include <iostream>
 #include <list>
 #include <sstream>
@@ -67,7 +68,7 @@ DinoGUI::DinoGUI(int argc, char** argv, RefPtr<Xml> xml)
     dlg.run();
   }
   
-  if (!init_lash(argc, argv)) {
+  if (!init_lash(argc, argv) &&!std::getenv("LADISH_APP_NAME")) {
     MessageDialog dlg("Could not initialise LASH! You will not be able "
 		      "to save your session.", false, MESSAGE_WARNING);
     dlg.run();
@@ -75,6 +76,7 @@ DinoGUI::DinoGUI(int argc, char** argv, RefPtr<Xml> xml)
   
   m_window = w<Gtk::Window>(xml, "main_window");
   m_about_dialog = w<AboutDialog>(xml, "dlg_about");
+  m_about_dialog->set_transient_for(*m_window);
   m_about_dialog->set_copyright("\u00A9 " CR_YEAR " Lars Luthman "
 				"<larsl@users.sourceforge.net>");
   m_about_dialog->set_version(PACKAGE_VERSION);
@@ -94,6 +96,16 @@ DinoGUI::DinoGUI(int argc, char** argv, RefPtr<Xml> xml)
   reset_gui();
   
   m_window->show_all();
+
+  if (argc == 2) {
+    //dbg1<<"arg: "<<argv[1]<<endl;
+    m_filename = argv[1];
+  }
+  else {
+    m_filename = "output.dino";
+  }
+
+  slot_file_open();
 }
 
 
@@ -102,22 +114,32 @@ Gtk::Window* DinoGUI::get_window() {
 }
 
 
+void DinoGUI::save() {
+  m_song.write_file(m_filename);
+}
+
+
 void DinoGUI::slot_file_open() {
   m_seq.stop();
-  m_song.load_file("output.dino");
+  try {
+    m_song.load_file(m_filename);
+  }
+  catch (...) {
+    m_song.clear();
+    m_song.set_length(32);
+  }
   reset_gui();
-  m_seq.reset_ports();
   m_seq.go_to_beat(0);
 }
 
 
 void DinoGUI::slot_file_save() {
-  m_song.write_file("output.dino");
+  save();
 }
 
 
 void DinoGUI::slot_file_save_as() {
-  m_song.write_file("output.dino");
+  save();
 }
 
 
