@@ -50,6 +50,8 @@ public:
   DinoGUI(int argc, char** argv, Glib::RefPtr<Gnome::Glade::Xml> xml);
   
   Gtk::Window* get_window();
+
+  void save();
   
 private:
 
@@ -121,6 +123,8 @@ private:
   Dino::Song m_song;
     
   lash_client_t* m_lash_client;
+
+  string m_filename;
 };
 
 
